@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import heapq
 from collections import deque
 from functools import cached_property
 from typing import Any, Deque, Dict, FrozenSet, Iterable, List, Optional, Set, Tuple
@@ -30,10 +31,6 @@ class Ramp:
     def _height_map(self):
         return self.__game_info.terrain_height
 
-    @cached_property
-    def _placement_grid(self):
-        return self.__game_info.placement_grid
-
     @cached_property
     def size(self) -> int:
         return len(self._points)
@@ -62,18 +59,13 @@ class Ramp:
     @cached_property
     def upper2_for_ramp_wall(self) -> FrozenSet[Point2]:
         """ Returns the 2 upper ramp points of the main base ramp required for the supply depot and barracks placement properties used in this file. """
-        if len(self.upper) > 5:
-            # NOTE: this was way too slow on large ramps
-            return frozenset()  # HACK: makes this work for now
-            # FIXME: please do
-
-        return frozenset(sorted(self.upper, key=lambda x: x.distance_to_point2(self.bottom_center), reverse=True)[:2])
+        # From bottom center, find 2 points that are furthest away (within the same ramp)
+        return frozenset(heapq.nlargest(2, self.upper, key=lambda x: x.distance_to_point2(self.bottom_center)))
 
     @cached_property
     def top_center(self) -> Point2:
-        upper = self.upper
-        length = len(upper)
-        pos = Point2((sum(p.x for p in upper) / length, sum(p.y for p in upper) / length))
+        length = len(self.upper)
+        pos = Point2((sum(p.x for p in self.upper) / length, sum(p.y for p in self.upper) / length))
         return pos
 
     @cached_property
@@ -91,9 +83,8 @@ class Ramp:
 
     @cached_property
     def bottom_center(self) -> Point2:
-        lower = self.lower
-        length = len(lower)
-        pos = Point2((sum(p.x for p in lower) / length, sum(p.y for p in lower) / length))
+        length = len(self.lower)
+        pos = Point2((sum(p.x for p in self.lower) / length, sum(p.y for p in self.lower) / length))
         return pos
 
     @cached_property
@@ -140,11 +131,11 @@ class Ramp:
             p1 = points.pop().offset((self.x_offset, self.y_offset))
             p2 = points.pop().offset((self.x_offset, self.y_offset))
             center = p1.towards(p2, p1.distance_to_point2(p2) / 2)
-            depotPosition = self.depot_in_middle
-            if depotPosition is None:
+            depot_position = self.depot_in_middle
+            if depot_position is None:
                 return frozenset()
             # Offset from middle depot to corner depots is (2, 1)
-            intersects = center.circle_intersection(depotPosition, 5**0.5)
+            intersects = center.circle_intersection(depot_position, 5**0.5)
             return intersects
         raise Exception("Not implemented. Trying to access a ramp that has a wrong amount of upper points.")
 
@@ -182,13 +173,13 @@ class Ramp:
         return middle + 6 * direction
 
     @cached_property
-    def protoss_wall_buildings(self) -> List[Point2]:
+    def protoss_wall_buildings(self) -> FrozenSet[Point2]:
         """
         List of two positions for 3x3 buildings that form a wall with a spot for a one unit block.
         These buildings can be powered by a pylon on the protoss_wall_pylon position.
         """
         if len(self.upper) not in {2, 5}:
-            return []
+            return frozenset()
         if len(self.upper2_for_ramp_wall) == 2:
             middle = self.depot_in_middle
             # direction up the ramp
@@ -199,7 +190,7 @@ class Ramp:
             )
             wall1 = sorted_depots[1].offset(direction)
             wall2 = middle + direction + (middle - wall1) / 1.5
-            return [wall1, wall2]
+            return frozenset([wall1, wall2])
         raise Exception("Not implemented. Trying to access a ramp that has a wrong amount of upper points.")
 
     @cached_property
@@ -230,11 +221,11 @@ class GameInfo:
         self.map_size: Size = Size.from_proto(self._proto.start_raw.map_size)
 
         # self.pathing_grid[point]: if 0, point is not pathable, if 1, point is pathable
-        self.pathing_grid: PixelMap = PixelMap(self._proto.start_raw.pathing_grid, in_bits=True, mirrored=False)
+        self.pathing_grid: PixelMap = PixelMap(self._proto.start_raw.pathing_grid, in_bits=True)
         # self.terrain_height[point]: returns the height in range of 0 to 255 at that point
-        self.terrain_height: PixelMap = PixelMap(self._proto.start_raw.terrain_height, mirrored=False)
+        self.terrain_height: PixelMap = PixelMap(self._proto.start_raw.terrain_height)
         # self.placement_grid[point]: if 0, point is not placeable, if 1, point is pathable
-        self.placement_grid: PixelMap = PixelMap(self._proto.start_raw.placement_grid, in_bits=True, mirrored=False)
+        self.placement_grid: PixelMap = PixelMap(self._proto.start_raw.placement_grid, in_bits=True)
         self.playable_area = Rect.from_proto(self._proto.start_raw.playable_area)
         self.map_center = self.playable_area.center
         self.map_ramps: List[Ramp] = None  # Filled later by BotAI._prepare_first_step
@@ -285,7 +276,7 @@ class GameInfo:
         def paint(pt: Point2) -> None:
             picture[pt.y][pt.x] = current_color
 
-        nearby = [(a, b) for a in [-1, 0, 1] for b in [-1, 0, 1] if a != 0 or b != 0]
+        nearby: List[Tuple[int, int]] = [(a, b) for a in [-1, 0, 1] for b in [-1, 0, 1] if a != 0 or b != 0]
 
         remaining: Set[Point2] = set(points)
         for point in remaining:
@@ -303,6 +294,7 @@ class GameInfo:
                 base: Point2 = queue.popleft()
                 for offset in nearby:
                     px, py = base.x + offset[0], base.y + offset[1]
+                    # Do we ever reach out of map bounds?
                     if not (0 <= px < map_width and 0 <= py < map_height):
                         continue
                     if picture[py][px] != NOT_COLORED_YET:
